@@ -2,7 +2,8 @@ from typing import List
 
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
-from checkov.common.util.secrets import string_has_secrets
+from checkov.common.util.secrets import get_secrets_from_string
+
 
 class EC2Credentials(BaseResourceCheck):
     def __init__(self):
@@ -20,7 +21,10 @@ class EC2Credentials(BaseResourceCheck):
                 # on Yaml or JSON CF Templates and how the B64 conversion is done.
                 user_data_str = str(user_data)
                 if isinstance(user_data_str, str):
-                    if string_has_secrets(user_data_str):
+                    secrets = get_secrets_from_string(str(user_data_str))
+                    if secrets:
+                        for idx, secret in enumerate(secrets):
+                            conf[f'{self.id}_secret_{idx}'] = secret
                         return CheckResult.FAILED
         return CheckResult.PASSED
 
