@@ -25,7 +25,9 @@ class ConnectionOneExistsSolver(ConnectionExistsSolver):
             vertices_under_connected_resources_types,
         )
 
-    def get_operation(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
-        passed, failed = super().get_operation(graph_connector)
+    def get_operation(self, graph_connector: DiGraph) -> \
+            Tuple[List[Dict[str, Any]], List[Dict[str, Any]], List[Dict[str, Any]]]:
+        passed, failed, unknown = super().get_operation(graph_connector)
         failed = [f for f in failed if f not in passed]
-        return passed, failed
+        unknown = [u for u in unknown if u not in passed]
+        return passed, failed, unknown
