@@ -6,7 +6,8 @@ from __future__ import annotations
 
 import json
 import logging
-from typing import Any, Dict
+from pathlib import Path
+from typing import Any
 
 from charset_normalizer import from_path
 
@@ -16,31 +17,35 @@ from checkov.common.parsers.json.errors import DecodeError
 LOGGER = logging.getLogger(__name__)
 
 
-def load(filename: str, allow_nulls: bool = True) -> tuple[dict[str, Any], list[tuple[int, str]]]:
+def load(
+    filename: str | Path, allow_nulls: bool = True, content: str | None = None
+) -> tuple[dict[str, Any], list[tuple[int, str]]]:
     """
     Load the given JSON file
     """
 
     try:
-        with open(filename) as fp:
-            content = fp.read()
+        if not content:
+            file_path = filename if isinstance(filename, Path) else Path(filename)
+            content = file_path.read_text()
     except UnicodeDecodeError:
         LOGGER.info(f"Encoding for file {filename} is not UTF-8, trying to detect it")
         content = str(from_path(filename).best())  # type:ignore[arg-type]  # somehow str is not recognized as PathLike
 
     file_lines = [(idx + 1, line) for idx, line in enumerate(content.splitlines(keepends=True))]
 
-    return (json.loads(content, cls=Decoder, allow_nulls=allow_nulls), file_lines)
+    return json.loads(content, cls=Decoder, allow_nulls=allow_nulls), file_lines
 
 
 def parse(
-    filename: str, allow_nulls: bool = True, out_parsing_errors: Dict[str, str] | None = None
-) -> tuple[dict[str, Any] | list[dict[str, Any]] | None, list[tuple[int, str]] | None]:
-    template = None
-    template_lines = None
+    filename: str,
+    allow_nulls: bool = True,
+    out_parsing_errors: dict[str, str] | None = None,
+    file_content: str | None = None,
+) -> tuple[dict[str, Any] | list[dict[str, Any]], list[tuple[int, str]]] | None:
     error: Exception | None = None
     try:
-        (template, template_lines) = load(filename, allow_nulls)
+        return load(filename=filename, allow_nulls=allow_nulls, content=file_content)
     except DecodeError as e:
         logging.debug(f'Got DecodeError parsing file {filename}', exc_info=True)
         error = e
@@ -60,4 +65,4 @@ def parse(
             out_parsing_errors = {}
         out_parsing_errors[filename] = str(error)
 
-    return (template, template_lines)
+    return None
