@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Any
+
 from jsonpath_ng import parse
 
 from checkov.common.models.enums import CheckResult, CheckCategories
@@ -7,7 +11,7 @@ from checkov.json_doc.enums import BlockType
 
 
 class GithubSSO(BaseGithubCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Ensure GitHub organization security settings require SSO"
         id = "CKV_GITHUB_2"
         categories = [CheckCategories.SUPPLY_CHAIN]
@@ -19,15 +23,16 @@ class GithubSSO(BaseGithubCheck):
             block_type=BlockType.DOCUMENT
         )
 
-    def scan_entity_conf(self, conf):
+    def scan_entity_conf(self, conf: dict[str, Any], entity_type: str) -> CheckResult | None:  # type:ignore[override]
         if org_security_schema.validate(conf):
             jsonpath_expression = parse("$..{}".format(self.get_evaluated_keys()[0].replace("/", ".")))
             if len(jsonpath_expression.find(conf)) > 0:
                 return CheckResult.PASSED
             else:
                 return CheckResult.FAILED
+        return None
 
-    def get_evaluated_keys(self):
+    def get_evaluated_keys(self) -> list[str]:
         return ['data/organization/samlIdentityProvider/ssoUrl']
 
 
