@@ -15,6 +15,7 @@ import yaml
 from typing import Optional, Dict, Any, TextIO, TYPE_CHECKING
 
 from checkov.common.graph.graph_builder import CustomAttributes
+from checkov.common.images.image_referencer import fix_related_resource_ids
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report
 from checkov.common.bridgecrew.check_type import CheckType
@@ -49,6 +50,25 @@ class K8sKustomizeRunner(K8sRunner):
         self.report_mutator_data: "dict[str, dict[str, Any]]" = {}
         self.pbar.turn_off_progress_bar()
 
+    def run(
+        self,
+        root_folder: str | None,
+        external_checks_dir: list[str] | None = None,
+        files: list[str] | None = None,
+        runner_filter: RunnerFilter | None = None,
+        collect_skip_comments: bool = True
+    ) -> Report | list[Report]:
+        results = super().run(root_folder, external_checks_dir=external_checks_dir, runner_filter=runner_filter)
+
+        sca_image_report = None
+        if isinstance(results, list):
+            sca_image_report = next(result for result in results if result.check_type == CheckType.SCA_IMAGE)
+
+        if root_folder is not None:
+            fix_related_resource_ids(report=sca_image_report, tmp_dir=root_folder)
+
+        return results
+
     def set_external_data(
         self,
         definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None,
