@@ -9,12 +9,23 @@ class MinimiseCapabilities(BaseResourceCheck):
         name = "Minimise the admission of containers with capabilities assigned"
         id = "CKV_K8S_37"
 
-        supported_resources = ['kubernetes_pod', 'kubernetes_pod_v1']
+        supported_resources = ['kubernetes_pod', "kubernetes_pod_v1",
+                               'kubernetes_deployment', 'kubernetes_deployment_v1']
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf) -> CheckResult:
         spec = conf.get('spec', [None])[0]
+        evaluated_keys_path = "spec"
+
+        template = spec.get("template")
+        if template and isinstance(template, list):
+            template = template[0]
+            template_spec = template.get("spec")
+            if template_spec and isinstance(template_spec, list):
+                spec = template_spec[0]
+                evaluated_keys_path = f'{evaluated_keys_path}/[0]/template/[0]/spec'
+
         if isinstance(spec, dict) and spec.get("container"):
             containers = spec.get("container")
 
@@ -28,11 +39,11 @@ class MinimiseCapabilities(BaseResourceCheck):
                         if capabilities.get("drop") and isinstance(capabilities.get("drop"), list):
                             drop = capabilities.get("drop")[0]
                             if not any(item in ("ALL", "all") for item in drop):
-                                self.evaluated_keys = [f'spec/[0]/container/[{idx}]/'
+                                self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/'
                                                        f'security_context/[0]/capabilities/drop']
                                 return CheckResult.FAILED
                         else:
-                            self.evaluated_keys = [f'spec/[0]/container/[{idx}]/'
+                            self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/'
                                                    f'security_context/[0]/capabilities']
                             return CheckResult.FAILED
         return CheckResult.PASSED
